![PyPI - Version](https://img.shields.io/pypi/v/idml2docbook)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/yanntrividic/idml2docbook/publish.yml)
![GitHub License](https://img.shields.io/github/license/yanntrividic/idml2docbook)

# idml2docbook

This Python package converts IDML files to DocBook 5.1.

## Installation

You can install and download this package using 

The main dependencies are:

* Python 3.x
* Java 1.7+
* idml2xml-frontend
* A recent version of bash (not a problem on Linux, but macOS distributes an old version of bash)